@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2026 Zabbix SIA
+** Copyright 2001-2023 Zabbix SIA
 **
 ** Licensed under the Apache License, Version 2.0 (the "License");
 ** you may not use this file except in compliance with the License.
@@ -20,9 +20,9 @@ package handlers
 import (
 	"errors"
 
+	"git.zabbix.com/ap/plugin-support/log"
+	"git.zabbix.com/ap/plugin-support/uri"
 	"go.mongodb.org/mongo-driver/mongo/options"
-	"golang.zabbix.com/sdk/log"
-	"golang.zabbix.com/sdk/uri"
 )
 
 const (
